   Creative


![picture alt]( https://media.giphy.com/media/HoIrPgqTBiB2XvVEf7/giphy.gif "Title is optional")




# Global Tool Windows

global_tools_win Windows üzerinde çalışan özellikli bir Araç(Tool)

## Installation

global_tools_win Yüklemek için paket yöneticisini [pip](https://pip.pypa.io/en/stable/) kullanın .

```
pip install global_tools_win
```

## Usage

```python
global_tools_win.main(x='h')
#h = Help Menüsünü açar 
```

## Contributing
Çekme istekleri kabul edilir. Büyük değişiklikler için lütfen önce neyi değiştirmek istediğinizi tartışmak üzere bir konu açın.


Lütfen testleri uygun şekilde güncellediğinizden emin olun.

## License
[MIT](https://choosealicense.com/licenses/mit/)





# GlobalToolWindows

### **Options**
- 01  Port Scanner
- 02  Net Ping Clear
- 03  Net Password Show
- 04  Instagram User İnfo
- 05  Password Creativ
- 06  Web IP Adresi
- 07  Win10 Logo
- 08  QR Code Creativ
- 09  Instagram PP download
- 10 DNS Reset
- 11 Proxy Reset
- 12 IP Tracker
